#include "utils.h"

#ifdef Q_WS_MAEMO_5
#include <QMaemo5InformationBox>


void show_information_note  (QWidget * w, const QString & t)
{
    QMaemo5InformationBox *box = new QMaemo5InformationBox(w);
    QTextBrowser *textBrowser = new QTextBrowser(box);
    textBrowser->setText(t);
    box->setWidget(textBrowser);
    box->setTimeout(QMaemo5InformationBox::NoTimeout);
    box->exec();

//  GtkWidget *window, *note;
//  gint response;
//  note = hildon_note_new_information (NULL, t.toUtf8());
//  response = gtk_dialog_run (GTK_DIALOG (note));
// // if (response == GTK_RESPONSE_DELETE_EVENT)
// //   g_debug ("%s: GTK_RESPONSE_DELETE_EVENT", __FUNCTION__);
//  gtk_object_destroy (GTK_OBJECT (note));
}


void show_banner  (QWidget * w, const QString & t)
{
	QMaemo5InformationBox::information(w, t, QMaemo5InformationBox::DefaultTimeout);

//	GtkWidget *window, *banner;
//
//	if (w != NULL)
//		banner = hildon_banner_show_information((GtkWidget *)w->nativeParentWidget(), NULL, t.toUtf8());
//	else
//		banner = hildon_banner_show_information(NULL, NULL, t.toUtf8());
//
//	hildon_banner_set_timeout (HILDON_BANNER (banner), 2000);
//
//    //gtk_object_destroy (GTK_OBJECT (note));
}
#endif
